# -*- coding: utf-8 -*-
from time import sleep
import smbus
import math

def resetPCA9685():
    bus.write_byte_data(address_pca9685, 0x00, 0x00)

def setPCA9685Freq(freq):
    freq = 0.9*freq # Arduinoのライブラリより
    prescaleval = 25000000.0    # 25MHz
    prescaleval /= 4096.0       # 12-bit
    prescaleval /= float(freq)
    prescaleval -= 1.0
    prescale = int(math.floor(prescaleval + 0.5))
    oldmode = bus.read_byte_data(address_pca9685, 0x00)
    newmode = (oldmode & 0x7F) | 0x10             # スリープモード
    bus.write_byte_data(address_pca9685, 0x00, newmode) # スリープモードへ
    bus.write_byte_data(address_pca9685, 0xFE, prescale) # プリスケーラーをセット
    bus.write_byte_data(address_pca9685, 0x00, oldmode)
    sleep(0.005)
    bus.write_byte_data(address_pca9685, 0x00, oldmode | 0xa1)

def setPCA9685Duty(channel, on, off):
    channelpos = 0x6 + 4*channel
    try:
        bus.write_i2c_block_data(address_pca9685, channelpos, [on&0xFF, on>>8, off&0xFF, off>>8] )
    except IOError:
        pass

bus = smbus.SMBus(1)
address_pca9685 = 0x40
servo_min = 126  # Min pulse length out of 4096
servo_max = 426  # Max pulse length out of 4096
servo_zero = 276 # Zero Pusle length out of 4960

resetPCA9685()
setPCA9685Freq(50)

setPCA9685Duty(0, 0, servo_zero)
setPCA9685Duty(1, 0, servo_zero)

Camera_H = servo_zero
Camera_V = servo_zero
angle_maxV = 75
angle_minV = -75
m=(servo_min-servo_max)/(angle_maxV-angle_minV)

delta = 2
speed = 0.05

angle_H = float(input('Horizontal Target Degree; '))
angle_V = float(input('Vertical   Target Degree: '))
Target_H = int( m * angle_H + servo_zero + 0.5)
Target_V = int( m * angle_V + servo_zero + 0.5)

# print "Target_H: ",Target_H,
# print "Target_V: ",Target_V

try:
    while abs(Target_H - Camera_H) >3 and Camera_H < servo_max and Camera_H > servo_min:
        if Target_H - Camera_H > 0 :
            Camera_H += delta
        else :
            Camera_H -= delta

        setPCA9685Duty(0, 0, Camera_H)
        sleep(speed)
    
    while abs(Target_V - Camera_V) >3 and Camera_V < servo_max and Camera_V > servo_min:
        if Target_V - Camera_V > 0 :
            Camera_V += delta
        else :
            Camera_V -= delta

        setPCA9685Duty(1, 0, Camera_V)
        sleep(speed)
        
except KeyboardInterrupt:
    pass
print "Mission Excuted"
